@@ -1,8 +1,12 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+
 #include <QMainWindow>
 #include <QDebug>
+#include <QSettings>
+#include <QFileDialog>
+
 
 namespace Ui {
     class MainWindow;
@@ -16,12 +20,19 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+
 private:
     Ui::MainWindow *ui;
 
+
+
 private slots:
+    void on_pushButton_clicked();
+    void on_pushButton_4_clicked();
     void on_pushButton_2_clicked();
     void on_pushButton_3_clicked();
+    void writeSettings();
+    void readSettings();
 };
 
 #endif // MAINWINDOW_H
